@@ -391,11 +391,13 @@ class Prefetch:
 
     :param relation: Related field name.
     :param queryset: Custom QuerySet to use for prefetching.
+    :param to_attr: Sets the result of the prefetch operation to a custom attribute.
     """
 
-    __slots__ = ("relation", "queryset")
+    __slots__ = ("relation", "queryset", "to_attr")
 
-    def __init__(self, relation: str, queryset: "QuerySet") -> None:
+    def __init__(self, relation: str, queryset: "QuerySet", to_attr: Optional[str] = None) -> None:
+        self.to_attr = to_attr
         self.relation = relation
         self.queryset = queryset
         self.queryset.query = copy(self.queryset.model._meta.basequery)
@@ -418,7 +420,9 @@ class Prefetch:
             if first_level_field not in queryset._prefetch_map.keys():
                 queryset._prefetch_map[first_level_field] = set()
             queryset._prefetch_map[first_level_field].add(
-                Prefetch(forwarded_prefetch, self.queryset)
+                Prefetch(forwarded_prefetch, self.queryset, to_attr=self.to_attr)
             )
         else:
-            queryset._prefetch_queries[first_level_field] = self.queryset
+            queryset._prefetch_queries.setdefault(first_level_field, []).append(
+                (self.to_attr, self.queryset)
+            )
